@@ -26,7 +26,7 @@ package Net::ZooKeeper;
 require Exporter;
 require XSLoader;
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 our @ISA = qw(Exporter);
 
@@ -55,6 +55,7 @@ our %EXPORT_TAGS = (
         ZAUTHFAILED
         ZCLOSING
         ZNOTHING
+        ZSESSIONMOVED
     )],
     'node_flags' => [qw(
         ZOO_EPHEMERAL
@@ -276,9 +277,9 @@ created by C<fork()>.
 =head2 Signals
 
 The ZooKeeper C API uses TCP connections to communicate with
-the ZooKeeper cluster.  These connections may generate SIGPIPE
+the ZooKeeper cluster.  In older ZooKeeper versions(before 3.4.0), these connections may generate SIGPIPE
 signals when they encounter errors, such as when a connection
-is terminated by a ZooKeeper server.  Therefore most applications
+is terminated by a ZooKeeper server.  Therefore applications using older ZooKeeper versions
 will want to trap or ignore SIGPIPE signals, e.g.:
 
   local $SIG{'PIPE'} = 'IGNORE';
@@ -368,7 +369,7 @@ required by ZooKeeper.
 
 =head2 Logging
 
-As of ZooKeeper version 3.1.1, logging in the C client code is
+As of ZooKeeper version 3.2.0, logging in the C client code is
 implemented with a single, shared file handle to which all
 of the internal POSIX threads write log messages; by default,
 this file handle is attached to STDERR.
